@@ -1,5 +1,5 @@
-from django.contrib.postgres.fields import JSONField
-from django.db.models import CharField
+# from django.contrib.postgres.fields import JSONField
+from django.db.models import CharField, JSONField
 from isc_common.fields import Field
 
 
