@@ -10,7 +10,7 @@ from django.db.models import QuerySet, Model
 from django.forms import model_to_dict
 from websocket import create_connection
 
-from isc_common import setAttr, Wrapper
+from isc_common import setAttr, Wrapper, user_name_anonim
 from isc_common.common.functions import Common
 from isc_common.http.DSRequest import RequestData, DSRequest
 from isc_common.http.RPCResponse import RPCResponse, RPCResponseConstant
@@ -66,8 +66,11 @@ class Body:
             return User.objects.get(id=self.body.httpHeaders.USER_ID).username
         else:
             if self.session != None and self.session._session != None:
-                return self.session._session.get('ws_channel').split('_')[1]
-            raise Exception('user not enable type')
+                ws_channel = self.session._session.get('ws_channel')
+                if ws_channel != None:
+                    return ws_channel.split('_')[1]
+                else:
+                    return user_name_anonim
 
     @property
     def user(self):
@@ -84,17 +87,14 @@ class Body:
                 try:
                     ws_channel = self.session._session.get('ws_channel')
                     if ws_channel != None:
-                        return User.objects.get(username=self.session._session.get('ws_channel').split('_')[1])
+                        return User.objects.get(username=ws_channel.split('_')[1])
                     else:
-                        return None
+                        return User.objects.get(username=user_name_anonim)
                 except User.DoesNotExist:
                     raise Exception('user not enable type')
             else:
                 raise Exception('user not enable type')
 
-            raise Exception('user not enable type')
-
-
 def JsonWSResponseWithException(printing=False, printing_res=False):
     try:
         class JE:
