@@ -18,10 +18,19 @@ logger = logging.getLogger(__name__)
 
 class CommonQuerySet(QuerySet):
 
-    # def filter(self, *args, **kwargs):
-    #     if self.alive_only:
-    #         setAttr(kwargs, 'deleted_at__isnull', True)
-    #     return super().filter(*args, **kwargs)
+    def soft_restore(self):
+        res = super().update(deleted_at=None)
+        return res
+
+    def hard_delete(self):
+        res = super().delete()
+        return res
+
+    def alive(self):
+        return self.filter(deleted_at=None)
+
+    def dead(self):
+        return self.exclude(deleted_at=None)
 
     def __init__(self, model=None, query=None, using=None, hints=None, alive_only=True, enabledAll=False):
         self.alive_only = alive_only
@@ -695,6 +704,10 @@ class CommonManager(Manager):
                     setAttr(cloned_data, 'props', props)
                 if request.get_id():
                     delAttr(cloned_data, 'id')
+                    parent = cloned_data.get('parent')
+                    if isinstance(parent, int):
+                        delAttr(cloned_data, 'parent')
+                        setAttr(cloned_data, 'parent_id', parent)
                     super().update_or_create(id=request.get_id(), defaults=cloned_data)
                 else:
                     new_item = super().create(**cloned_data)
