@@ -1,7 +1,7 @@
 from django.conf import settings
 
 
-def make_shedurer_tasks():
+def make_shedurer_tasks(func=None, when='1s', start=None, args=None, kwargs=None, name=None, repeating=True, threaded=True):
     from isc_common.management.commands.grop_tmp_mat_views import grop_mat_views
     from pyriodic import Scheduler, DurationJob
 
@@ -11,7 +11,10 @@ def make_shedurer_tasks():
         grop_mat_views(prefix='ready')
         grop_mat_views(prefix='tmp')
 
-    s.add_job(DurationJob(drop_tbl, when=settings.SHEDULLER_PERIOD, name='grop_ready_mat_views'))
+    if callable(func):
+        s.add_job(DurationJob(func=func, when=when, name=name, start=start, args=args, kwargs=kwargs, repeating=repeating, threaded=threaded))
+    else:
+        s.add_job(DurationJob(drop_tbl, when=settings.SHEDULLER_PERIOD, name='grop_ready_mat_views'))
 
     # print(s.next_run_times())
     return s
